Skip to content
Open
Changes from all commits
Commits
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
12 changes: 6 additions & 6 deletions src/dtypes.cuh
Original file line number Diff line number Diff line change
Expand Up @@ -13,9 +13,9 @@ namespace cumesh {
struct __align__(16) Vec3f {
float x, y, z;

__device__ __forceinline__ Vec3f();
__device__ __forceinline__ Vec3f(float x, float y, float z);
__device__ __forceinline__ Vec3f(float3 v);
__host__ __device__ __forceinline__ Vec3f();
__host__ __device__ __forceinline__ Vec3f(float x, float y, float z);
__host__ __device__ __forceinline__ Vec3f(float3 v);
__device__ __forceinline__ Vec3f operator+(const Vec3f& o) const;
__device__ __forceinline__ Vec3f& operator+=(const Vec3f& o);
__device__ __forceinline__ Vec3f operator-(const Vec3f& o) const;
Expand Down Expand Up @@ -55,19 +55,19 @@ struct __align__(16) QEM
};


__device__ __forceinline__ Vec3f::Vec3f() {
__host__ __device__ __forceinline__ Vec3f::Vec3f() {
x = 0.0f;
y = 0.0f;
z = 0.0f;
}

__device__ __forceinline__ Vec3f::Vec3f(float x, float y, float z) {
__host__ __device__ __forceinline__ Vec3f::Vec3f(float x, float y, float z) {
this->x = x;
this->y = y;
this->z = z;
}

__device__ __forceinline__ Vec3f::Vec3f(float3 v) {
__host__ __device__ __forceinline__ Vec3f::Vec3f(float3 v) {
x = v.x;
y = v.y;
z = v.z;
Expand Down